@@ -774,7 +774,7 @@ void ListPopupMenu::insert(MenuType m)
         m_actions[m] = addAction(Icon_Utils::BarIcon(Icon_Utils::it_Import_File), i18n("Import File(s)..."));
         break;
     case mt_Import_Project:
-        m_actions[m] = addAction(Icon_Utils::BarIcon(Icon_Utils::it_Import_Project), i18n("Import Project..."));
+        m_actions[m] = addAction(Icon_Utils::BarIcon(Icon_Utils::it_Import_Project), i18n("Import from Directory..."));
         break;
     case mt_Reset_Label_Positions:
         m_actions[m] = addAction(i18n("Reset Label Positions"));
@@ -1577,6 +1577,9 @@ void ListPopupMenu::insertSubMenuNew(MenuType type)
             break;
         case mt_On_Sequence_Diagram:
             insert(mt_Import_from_File, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Import_File), i18n("Import stack trace..."));
+            insert(mt_Object, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Object), i18n("Object..."));
+            insert(mt_FloatText, menu);
+            break;
         case mt_On_Collaboration_Diagram:
             insert(mt_Object, menu, Icon_Utils::SmallIcon(Icon_Utils::it_Object), i18n("Object..."));
             insert(mt_FloatText, menu);
