@@ -18,34 +18,14 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <QtTest>
+#include "TEST_basictypes.h"
 
+// app includes
 #include "basictypes.h"
 
-class TEST_basictypes : public QObject
-{
-    Q_OBJECT
-private slots:
-    void test_dynamic_cast();
-    void test_ModelType_toString();
-    void test_ModelType_fromString();
-    void test_ModelType_forLoop();
-    void test_Visibility_toString();
-    void test_Visibility_fromString();
-    void test_DiagramType_toString();
-    void test_DiagramType_fromString();
-    void test_DiagramType_forLoop();
-    void test_AssociationType_toString_fromString();
-    void test_SignatureType_toString_fromString();
-    void test_TextRole_toString_fromString();
-    void test_Changeability_toString_fromString();
-    void test_SequenceMessage_toString_fromString();
-    void test_RoleType_toString_fromString();
-    void test_ParameterDirection_toString_fromString();
-    void test_ProgrammingLanguage_toString_fromString();
-    void test_Region_toString_fromString();
-    void test_Corner_toString_fromString();
-};
+// qt includes
+#include <QtTest>
+#include <QDomDocument>
 
 //-----------------------------------------------------------------------------
 
@@ -61,14 +41,129 @@ class B : public A
 
 void TEST_basictypes::test_dynamic_cast()
 {
-    A *a1 = new A;
-    B* b1 = dynamic_cast<B*> (a1);
+    QScopedPointer<A> a1(new A);
+    B* b1 = dynamic_cast<B*> (a1.data());
     QVERIFY(!b1);
-    A *a2 = new B;
-    B* b2 = dynamic_cast<B*> (a2);
+    QScopedPointer<A> a2(new B);
+    B* b2 = dynamic_cast<B*> (a2.data());
     QVERIFY(b2);
-    delete a1;
-    delete a2;
+}
+
+void TEST_basictypes::test_QString_english()
+{
+    QLocale _default = QLocale();
+    QLocale english(QLocale::English);
+    QLocale::setDefault(english);
+
+    QString value1String(QLatin1String("123.456"));
+    float referenceValue = 123.456;
+    qreal referenceDValue = 123.456;
+
+    QString a = QString::number(referenceValue);
+    QCOMPARE(value1String, a);
+
+    bool ok;
+    float value = value1String.toFloat(&ok);
+    QVERIFY(ok);
+    QCOMPARE(value, referenceValue);
+    qreal dValue = value1String.toDouble(&ok);
+    QVERIFY(ok);
+    QCOMPARE(dValue, referenceDValue);
+    QLocale::setDefault(_default);
+}
+
+void TEST_basictypes::test_QString_non_english()
+{
+    QLocale _default = QLocale();
+    QLocale hungarian(QLocale::Hungarian);
+    QLocale::setDefault(hungarian);
+
+    QString value1String(QLatin1String("123.456"));
+    float referenceValue = 123.456;
+    qreal referenceDValue = 123.456;
+
+    QString a = QString::number(referenceValue);
+    QCOMPARE(value1String, a);
+
+    bool ok;
+    float value = value1String.toFloat(&ok);
+    QVERIFY(ok);
+    QCOMPARE(value, referenceValue);
+    qreal dValue = value1String.toDouble(&ok);
+    QVERIFY(ok);
+    QCOMPARE(dValue, referenceDValue);
+    QLocale::setDefault(_default);
+}
+
+void TEST_basictypes::test_DomDocument_english()
+{
+    QLocale _default = QLocale();
+    QLocale locale(QLocale::English);
+    QLocale::setDefault(locale);
+    QCOMPARE(QChar(QLatin1Char('.')), locale.decimalPoint());
+
+    float fVar = 123.456;
+    double dVar = 123.456;
+    QString refValue(QLatin1String("123.456"));
+    QString localeValue;
+    localeValue.replace(QLatin1Char('.'), _default.decimalPoint());
+
+    QDomDocument doc("test");
+    QDomElement root = doc.createElement("test");
+    doc.appendChild(root);
+    root.setAttribute("a", fVar);
+    QString xml = doc.toString();
+    QVERIFY2(xml.contains(refValue), xml.toLatin1().constData());
+
+    // caused by bug in Qt xml
+    root.setAttribute("a", dVar);
+    xml = doc.toString();
+    QVERIFY2(xml.contains(localeValue), xml.toLatin1().constData());
+
+    root.setAttribute("a", QString::number(fVar));
+    xml = doc.toString();
+    QVERIFY(xml.contains(refValue));
+
+    root.setAttribute("a", QString::number(dVar));
+    xml = doc.toString();
+    QVERIFY2(xml.contains(refValue), xml.toLatin1().constData());
+    QLocale::setDefault(_default);
+}
+
+void TEST_basictypes::test_DomDocument_non_english()
+{
+    QLocale _default = QLocale();
+    QLocale locale(QLocale::Hungarian);
+    QLocale::setDefault(locale);
+    QCOMPARE(QChar(QLatin1Char(',')), locale.decimalPoint());
+
+    float fVar = 123.456;
+    double dVar = 123.456;
+    QString refValue(QLatin1String("123.456"));
+    QString localeValue;
+    localeValue.replace(QLatin1Char('.'), _default.decimalPoint());
+
+    QDomDocument doc("test");
+    QDomElement root = doc.createElement("test");
+    doc.appendChild(root);
+
+    root.setAttribute("a", fVar);
+    QString xml = doc.toString();
+    QVERIFY2(xml.contains(refValue), xml.toLatin1().constData());
+
+    // caused by bug in Qt xml
+    root.setAttribute("a", dVar);
+    xml = doc.toString();
+    QVERIFY2(xml.contains(localeValue), xml.toLatin1().constData());
+
+    root.setAttribute("a", QString::number(fVar));
+    xml = doc.toString();
+    QVERIFY2(xml.contains(refValue), xml.toLatin1().constData());
+
+    root.setAttribute("a", QString::number(dVar));
+    xml = doc.toString();
+    QVERIFY2(xml.contains(refValue), xml.toLatin1().constData());
+    QLocale::setDefault(_default);
 }
 
 void TEST_basictypes::test_ModelType_toString()
@@ -361,4 +456,3 @@ void TEST_basictypes::test_Corner_toString_fromString()
 //-----------------------------------------------------------------------------
 
 QTEST_MAIN(TEST_basictypes)
-#include "test_basictypes.moc"
